@@ -69,7 +69,7 @@ mod ffi {
         pub fn timer_delete(timerid: timer_t);
     }
 
-    #[link(name = "os-timer-posix-c", lind = "static")]
+    #[link(name = "os-timer-posix-c", kind = "static")]
     extern "C" {
         pub fn posix_timer(clock: libc::c_int, cb: Callback, data: *mut libc::c_void) -> timer_t;
     }
@@ -226,7 +226,7 @@ impl Timer {
 
     ///Schedules timer to alarm periodically with `interval` with initial alarm of `timeout`.
     ///
-    ///Note that if timer has been scheduled before, but hasn't expire yet, it shall be cancelled.
+    ///Note that if timer has been scheduled before, but hasn't expire yet, behaviour is undefined (Callback may or may not be called).
     ///To prevent that user must `cancel` timer first.
     ///
     ///Returns `true` if successfully set, otherwise on error returns `false`
